# midd-media
Libraries and examples for CSCI 0145


## middsound

A library for interacting with sound. This provides a thin wrapper around the wave library. This also requires pygame for sound playback.


##middimage

Another thin wrapper to simplify the interface. This wraps pillow while providing an interface very close to that of middsound.

